

def prepare_timeboundary(filename):
    """Converting tide time series to NetCDF tms file.
    This is a 'throw-away' code taylor made for files like
    'Benchmark_2_input.txt' from the LWRU2 benchmark
    """

    print 'Preparing time boundary from %s' %filename
    from Numeric import array, zeros, Float, asarray

    fid = open(filename)

    #Skip first line
    line = fid.readline()

    #Read remaining lines
    lines = fid.readlines()
    fid.close()


    N = len(lines)
    T = zeros(N, Float)  #Time
    Q = zeros(N, Float)  #Values

    Told = 0.0
    Sold = ' '
    Lold = ' '
    for i, line in enumerate(lines):
        fields = line.split()

        #print fields

        l_time = (fields[0]+' '+fields[1])[0:-1]
        from time import strptime, mktime

        s_time = strptime(l_time,'%d/%m/%y  %H:%M:%S')

        #print s_time

        T[i] = float(mktime(s_time))

        if i==0:
            Tstart = T[0]

        T[i] = T[i] - Tstart

        if i>3270:
            T[i] = T[i]+3600

        if T[i]<Told :
            print Lold
            print l_time
            print Sold
            print s_time
            print Told
            print T[i]
            print i, T[i]-Told

        Q[i] = float(fields[2])

        Told = T[i]
        Sold = s_time
        Lold = l_time


    #Create tms file
    from Scientific.IO.NetCDF import NetCDFFile

    outfile = filename[:-4] + '.tms'
    print 'Writing to', outfile
    fid = NetCDFFile(outfile, 'w')

    fid.institution = 'Australian National University'
    fid.description = 'Input wave for Merimbula'
    fid.starttime = 0.0
    fid.createDimension('number_of_timesteps', len(T))
    fid.createVariable('time', Float, ('number_of_timesteps',))
    fid.variables['time'][:] = T

    fid.createVariable('stage', Float, ('number_of_timesteps',))
    fid.variables['stage'][:] = Q[:]

    fid.createVariable('xmomentum', Float, ('number_of_timesteps',))
    fid.variables['xmomentum'][:] = 0.0

    fid.createVariable('ymomentum', Float, ('number_of_timesteps',))
    fid.variables['ymomentum'][:] = 0.0

    fid.close()


#-------------------------------------------------------------
if __name__ == "__main__":
    filename = 'Eden_tide_Sept03.dat'
    print 'Open sea boundary condition from ',filename
    prepare_timeboundary(filename)

